==> elytratrims-fabric-3.9.0%2B1.21.1-sources.jar: dev/kikugie/elytratrims/mixin/common/RecipeManagerMixin.java <==
package dev.kikugie.elytratrims.mixin.common;

import com.llamalad7.mixinextras.injector.ModifyExpressionValue;
import com.llamalad7.mixinextras.sugar.Local;
import dev.kikugie.elytratrims.common.recipe.ETSmithingRecipe;
import net.minecraft.class_1860;
import net.minecraft.class_1863;
import net.minecraft.class_2960;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;

@Mixin(class_1863.class)
public class RecipeManagerMixin {
	//? if <1.21 && fabric {
	/*@ModifyExpressionValue(
		method = "apply(Ljava/util/Map;Lnet/minecraft/resource/ResourceManager;Lnet/minecraft/util/profiler/Profiler;)V",
		at = @At(
			value = "INVOKE",
			target = "Lnet/minecraft/recipe/RecipeManager;deserialize(Lnet/minecraft/util/Identifier;Lcom/google/gson/JsonObject;)Lnet/minecraft/recipe/Recipe;"
		)
	)
	private Recipe<?> modifyElytraRecipes(Recipe<?> original, @Local Identifier id) {
		return ETSmithingRecipe.match(original.getId(), original);
	}
	*///?} elif <1.21 {
	/*@ModifyExpressionValue(
		method = "apply(Ljava/util/Map;Lnet/minecraft/resource/ResourceManager;Lnet/minecraft/util/profiler/Profiler;)V",
		at = @At(
			value = "INVOKE",
			target = "Lnet/minecraft/recipe/RecipeManager;fromJson(Lnet/minecraft/util/Identifier;Lcom/google/gson/JsonObject;Lnet/minecraftforge/common/crafting/conditions/ICondition$IContext;)Lnet/minecraft/recipe/Recipe;"
		)
	)
	private Recipe<?> modifyElytraRecipes(Recipe<?> original, @Local Identifier id) {
		return ETSmithingRecipe.match(original.getId(), original);
	}
	*///?} elif fabric {
	@ModifyExpressionValue(
		method = "apply(Ljava/util/Map;Lnet/minecraft/resource/ResourceManager;Lnet/minecraft/util/profiler/Profiler;)V",
		at = @At(value = "INVOKE", target = "Lcom/mojang/serialization/DataResult;getOrThrow(Ljava/util/function/Function;)Ljava/lang/Object;")
	)
	private Object modifyElytraRecipes(Object original, @Local class_2960 id) {
		return ETSmithingRecipe.match(id, (class_1860<?>) original);
	}
	//?} else {
	/*@ModifyExpressionValue(
		method = "lambda$apply$0",
		at = @At(value = "INVOKE", target = "Lnet/neoforged/neoforge/common/conditions/WithConditions;carrier()Ljava/lang/Object;")
	)
	private static Object modifyElytraRecipes(Object original, @Local(argsOnly = true) Identifier id) {
		return ETSmithingRecipe.match(id, (Recipe<?>) original);
	}
	*///?}
}

==> elytratrims-fabric-3.9.1%2B1.21.1-sources.jar: dev/kikugie/elytratrims/mixin/common/RecipeManagerMixin.java <==
package dev.kikugie.elytratrims.mixin.common;

import com.llamalad7.mixinextras.injector.ModifyExpressionValue;
import com.llamalad7.mixinextras.sugar.Local;
import dev.kikugie.elytratrims.common.recipe.ETSmithingRecipe;
import net.minecraft.class_1860;
import net.minecraft.class_1863;
import net.minecraft.class_2960;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;

@Mixin(class_1863.class)
public class RecipeManagerMixin {
	//? if <1.21 && fabric {
	/*@ModifyExpressionValue(
		method = "apply(Ljava/util/Map;Lnet/minecraft/resource/ResourceManager;Lnet/minecraft/util/profiler/Profiler;)V",
		at = @At(
			value = "INVOKE",
			target = "Lnet/minecraft/recipe/RecipeManager;deserialize(Lnet/minecraft/util/Identifier;Lcom/google/gson/JsonObject;)Lnet/minecraft/recipe/Recipe;"
		)
	)
	private Recipe<?> modifyElytraRecipes(Recipe<?> original, @Local Identifier id) {
		return original == null ? null : ETSmithingRecipe.match(original.getId(), original);
	}
	*///?} elif <1.21 {
	/*@ModifyExpressionValue(
		method = "apply(Ljava/util/Map;Lnet/minecraft/resource/ResourceManager;Lnet/minecraft/util/profiler/Profiler;)V",
		at = @At(
			value = "INVOKE",
			target = "Lnet/minecraft/recipe/RecipeManager;fromJson(Lnet/minecraft/util/Identifier;Lcom/google/gson/JsonObject;Lnet/minecraftforge/common/crafting/conditions/ICondition$IContext;)Lnet/minecraft/recipe/Recipe;"
		)
	)
	private Recipe<?> modifyElytraRecipes(Recipe<?> original, @Local Identifier id) {
		return original == null ? null : ETSmithingRecipe.match(original.getId(), original);
	}
	*///?} elif fabric {
	@ModifyExpressionValue(
		method = "apply(Ljava/util/Map;Lnet/minecraft/resource/ResourceManager;Lnet/minecraft/util/profiler/Profiler;)V",
		at = @At(value = "INVOKE", target = "Lcom/mojang/serialization/DataResult;getOrThrow(Ljava/util/function/Function;)Ljava/lang/Object;")
	)
	private Object modifyElytraRecipes(Object original, @Local class_2960 id) {
		return original == null ? null : ETSmithingRecipe.match(id, (class_1860<?>) original);
	}
	//?} else {
	/*@ModifyExpressionValue(
		method = "lambda$apply$0",
		at = @At(value = "INVOKE", target = "Lnet/neoforged/neoforge/common/conditions/WithConditions;carrier()Ljava/lang/Object;")
	)
	private static Object modifyElytraRecipes(Object original, @Local(argsOnly = true) Identifier id) {
		return original == null ? null : ETSmithingRecipe.match(id, (Recipe<?>) original);
	}
	*///?}
}
